==> nextcloud-18.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/pt_BR.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidade",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "O centro de privacidade mostra onde seus dados estão armazenados e quem pode acessá-los, seja porque você compartilhou com eles ou porque são administradores.",
    "Remove external admin" : "Excluir a administração externa",
    "Add external admin" : "Adicionar administrador externo",
    "Your files are not protected by encryption." : "Seus arquivos não estão criptografados.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Seus arquivos estão criptografados com {linkopen}criptografia-lado-do-servidor ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Este servidor está protegido com criptografia-de-disco-completo.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Seus arquivos estão criptografados com {linkopen}criptografia-lado-do-servidor ↗{linkclose}. Adicionalmente, este servidor está protegido com criptografia-de-disco-completo.",
    "This server is using full-disk-encryption." : "Este servidor está usando criptografia-de-disco-completo.",
    "Change data location" : "Alterar a localização dos dados",
    "Your data is located in: " : "Seus dados estão em:",
    "The admin hasn't selected the location of the server yet." : "O administrador ainda não selecionou a localização do servidor.",
    "Please select a country" : "Selecione um país",
    "You don't have any shares with individual users." : "Você não tem compartilhamentos com usuários individuais.",
    "Somaliland" : "Somalilândia",
    "United Arab Emirates" : "Emirados Árabes Unidos",
    "Afghanistan" : "Afeganistão",
    "Albania" : "Albânia",
    "Armenia" : "Armênia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Azerbaijan" : "Azerbaijão",
    "Bosnia and Herzegowina" : "Bósnia e Herzegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolívia",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butão",
    "Botswana" : "Botsuana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canadá",
    "Democratic Republic of the Congo" : "República Democrática do Congo",
    "Central African Republic" : "República Centro-Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíça",
    "Cote d'Ivoire" : "Costa do Marfim",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Chipre",
    "Czech" : "Tcheca",
    "Germany" : "Alemanha",
    "Djibouti" : "Djibuti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algéria",
    "Ecuador" : "Equador",
    "Estonia" : "Estônia",
    "Egypt" : "Egito",
    "West Sahara" : "Saara Ocidental",
    "Eritrea" : "Eritréia",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Ilhas Falkland",
    "France" : "França",
    "Gabon" : "Gabão",
    "United Kingdom" : "Reino Unido",
    "Georgia" : "Georgia",
    "Ghana" : "Gana",
    "Greenland" : "Groenlândia",
    "Gambia" : "Gâmbia",
    "Guinea" : "Guiné",
    "Equatorial Guinea" : "Guiné Equatorial",
    "Greece" : "Grécia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guiné-Bissau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Croatia" : "Croácia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungria",
    "Indonesia" : "Indonésia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "India" : "Índia",
    "Iraq" : "Iraque",
    "Iran" : "Irã",
    "Iceland" : "Islândia",
    "Italy" : "Itália",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordânia",
    "Japan" : "Japão",
    "Kenya" : "Quênia",
    "Kyrgyzstan" : "Quirguistão",
    "Cambodia" : "Camboja",
    "North Korea" : "Coreia do Norte",
    "South Korea" : "Coreia do Sul",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Cazaquistão",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituânia",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letônia",
    "Libya" : "Líbia",
    "Morocco" : "Marrocos",
    "Moldova" : "Moldávia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedônia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongólia",
    "Mauritania" : "Mauritânia",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malásia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledônia",
    "Niger" : "Nigéria",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicarágua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Zelândia",
    "Oman" : "Omã",
    "Panama" : "Panamá",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Nova Guiné",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistão",
    "Poland" : "Polônia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Catar",
    "Romania" : "Romênia",
    "Serbia" : "Sérvia",
    "Russia" : "Rússia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arábia Saudita",
    "Solomon Islands" : "Ilhas Salomão",
    "Sudan" : "Sudão",
    "Sweden" : "Suécia",
    "Singapore" : "Cingapura",
    "Slovenia" : "Eslovênia",
    "Slovakia" : "Eslováquia",
    "Sierra Leone" : "Serra Leoa",
    "Senegal" : "Senegal",
    "Somalia" : "Somália",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudão do Sul",
    "El Salvador" : "El Salvador",
    "Syria" : "Síria",
    "Swaziland" : "Suazilândia",
    "Chad" : "Chade",
    "Fr. S. Antarctic Lands" : "Fr. S. Terras Antárticas",
    "Togo" : "Togo",
    "Thailand" : "Tailândia",
    "Tajikistan" : "Tajiquistão",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcomenistão",
    "Tunisia" : "Tunísia",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinidade e Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzânia",
    "Ukraine" : "Ucrânia",
    "Uganda" : "Uganda",
    "United States" : "Estados Unidos",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbequistão",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnã",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Iêmen",
    "South Africa" : "África do Sul",
    "Zambia" : "Zâmbia",
    "Zimbabwe" : "Zimbábue",
    "Your Nextcloud account" : "Sua conta Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Seus dados representam quem você é e podem ser facilmente usados. Na Nextcloud acreditamos que você tem o direito de decidir o que acontece com eles. O Nextcloud protege seus direitos conforme definido no Manifesto de Dados do Usuário!",
    "User Data Manifesto 2.0" : "Manifesto de Dados do Usuário 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definindo direitos básicos para as pessoas controlarem seus próprios dados na era da internet",
    "Control" : "Controle",
    "over user data access" : "sobre o acesso a dados do usuário",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Os dados carregados explicitamente e de bom grado por um usuário devem estar sob o controle final dele. Os usuários podem decidir quem tem acesso direto aos dados e com quais permissões e licenças esse acesso deve ser concedido.",
    "Knowledge" : "Conhecimento",
    "of how the data is stored" : "de como os dados são armazenados",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quando os dados são carregados em um provedor de serviços específico, os usuários devem ser informados sobre onde ele armazena os dados, por quanto tempo, em qual jurisdição o provedor de serviços específico opera e quais leis se aplicam.",
    "Freedom" : "Liberdade",
    "to choose a platform" : "escolher uma plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Os usuários podem extrair seus dados do serviço a qualquer momento sem qualquer bloqueio do fornecedor. Padrões abertos para formatos e protocolos são necessários para garantir isso.",
    "Learn more ↗" : "Saiba mais ↗",
    "Where is your data?" : "Onde estão seus dados?",
    "Who has access to your data?" : "Quem tem acesso aos seus dados?",
    "Administrators" : "Administradores",
    "People you shared with" : "Pessoas com quem você compartilhou",
    "Privacy policy" : "Política de privacidade",
    "Read the privacy policy." : "Leia a política de privacidade.",
    "Encryption" : "Criptografia"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/pt_BR.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidade",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "O centro de privacidade mostra onde seus dados estão armazenados e quem pode acessá-los, seja porque você compartilhou com eles ou porque são administradores.",
    "Remove external admin" : "Excluir a administração externa",
    "Add external admin" : "Adicionar administrador externo",
    "Name of external admin" : "Nome do administrador externo",
    "This server is using full-disk-encryption." : "Este servidor está usando criptografia-de-disco-completo.",
    "Your files are not protected by encryption." : "Seus arquivos não estão criptografados.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Seus arquivos estão criptografados com {linkopen}criptografia-lado-do-servidor ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Este servidor está protegido com criptografia-de-disco-completo.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Seus arquivos estão criptografados com {linkopen}criptografia-lado-do-servidor ↗{linkclose}. Adicionalmente, este servidor está protegido com criptografia-de-disco-completo.",
    "Your data is located in: " : "Seus dados estão em: ",
    "The admin hasn't selected the location of the server yet." : "O administrador ainda não selecionou a localização do servidor.",
    "Change data location" : "Alterar a localização dos dados",
    "Please select a region" : "Selecione uma região",
    "You don't have any shares with individual users." : "Você não tem compartilhamentos com usuários individuais.",
    "Somaliland" : "Somalilândia",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirados Árabes Unidos",
    "Afghanistan" : "Afeganistão",
    "Antigua and Barbuda" : "Antígua e Barbuda",
    "Anguilla" : "Anguila",
    "Albania" : "Albânia",
    "Armenia" : "Armênia",
    "Angola" : "Angola",
    "Antarctica" : "Antártica",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americana",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ilhas Aland",
    "Azerbaijan" : "Azerbaijão",
    "Bosnia and Herzegovina" : "Bósnia e Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Bahrain" : "Barém",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "São Bartolomeu",
    "Bermuda" : "Bermudas",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolívia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Santo Eustáquio e Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butão",
    "Bouvet Island" : "Ilha Bouvet",
    "Botswana" : "Botsuana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canadá",
    "Cocos (Keeling) Islands" : "Ilhas Cocos (Keeling)",
    "Democratic Republic of the Congo" : "República Democrática do Congo",
    "Central African Republic" : "República Centro-Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíça",
    "Cote d'Ivoire" : "Costa do Marfim",
    "Cook Islands" : "Ilhas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Ilha do Natal",
    "Cyprus" : "Chipre",
    "Czech" : "Tcheca",
    "Germany" : "Alemanha",
    "Djibouti" : "Djibuti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algéria",
    "Ecuador" : "Equador",
    "Estonia" : "Estônia",
    "Egypt" : "Egito",
    "West Sahara" : "Saara Ocidental",
    "Eritrea" : "Eritréia",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Ilhas Falkland",
    "Micronesia" : "Micronésia",
    "Faroe Islands" : "ilhas Faroé",
    "France" : "França",
    "Gabon" : "Gabão",
    "United Kingdom" : "Reino Unido",
    "Grenada" : "Granada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenlândia",
    "Gambia" : "Gâmbia",
    "Guinea" : "Guiné",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guiné Equatorial",
    "Greece" : "Grécia",
    "South Georgia and the South Sandwich Islands" : "Geórgia do Sul e Ilhas Sandwich do Sul",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guiné-Bissau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Ilha Heard e Ilhas McDonald",
    "Croatia" : "Croácia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungria",
    "Indonesia" : "Indonésia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Ilha de Man",
    "India" : "Índia",
    "British Indian Ocean Territory" : "Território Britânico do Oceano Índico",
    "Iraq" : "Iraque",
    "Iran" : "Irã",
    "Iceland" : "Islândia",
    "Italy" : "Itália",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordânia",
    "Japan" : "Japão",
    "Kenya" : "Quênia",
    "Kyrgyzstan" : "Quirguistão",
    "Cambodia" : "Camboja",
    "Kiribati" : "Kiribati",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "São Cristóvão e Neves",
    "North Korea" : "Coreia do Norte",
    "South Korea" : "Coreia do Sul",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Ilhas Cayman",
    "Kazakhstan" : "Cazaquistão",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Saint Lucia" : "Santa Lúcia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituânia",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letônia",
    "Libya" : "Líbia",
    "Morocco" : "Marrocos",
    "Monaco" : "Mônaco",
    "Moldova" : "Moldávia",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "San Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Ilhas Marshall",
    "Macedonia" : "Macedônia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongólia",
    "Macao" : "Macau",
    "Northern Mariana Islands" : "Ilhas Marianas do Norte",
    "Mauritania" : "Mauritânia",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurício",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malásia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledônia",
    "Niger" : "Nigéria",
    "Norfolk Island" : "Ilha Norfolk",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicarágua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niuê",
    "New Zealand" : "Nova Zelândia",
    "Oman" : "Omã",
    "Panama" : "Panamá",
    "Peru" : "Peru",
    "French Polynesia" : "Polinésia Francesa",
    "Papua New Guinea" : "Papua Nova Guiné",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistão",
    "Poland" : "Polônia",
    "Saint Pierre and Miquelon" : "São Pedro e Miquelão",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Catar",
    "Réunion" : "Reunião",
    "Romania" : "Romênia",
    "Serbia" : "Sérvia",
    "Russia" : "Rússia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arábia Saudita",
    "Solomon Islands" : "Ilhas Salomão",
    "Seychelles" : "Seicheles",
    "Sudan" : "Sudão",
    "Sweden" : "Suécia",
    "Singapore" : "Cingapura",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascensão e Tristão da Cunha",
    "Slovenia" : "Eslovênia",
    "Svalbard and Jan Mayen" : "Svalbard e Jan Mayen",
    "Slovakia" : "Eslováquia",
    "Sierra Leone" : "Serra Leoa",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somália",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudão do Sul",
    "Sao Tome and Principe" : "São Tome e Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "San Martin",
    "Syria" : "Síria",
    "Swaziland" : "Suazilândia",
    "Turks and Caicos Islands" : "Ilhas Turcas e Caicos",
    "Chad" : "Chade",
    "Fr. S. Antarctic Lands" : "Fr. S. Terras Antárticas",
    "Togo" : "Togo",
    "Thailand" : "Tailândia",
    "Tajikistan" : "Tajiquistão",
    "Tokelau" : "Toquelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcomenistão",
    "Tunisia" : "Tunísia",
    "Tonga" : "Tonganês",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinidade e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzânia",
    "Ukraine" : "Ucrânia",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Ilhas Menores Distantes dos Estados Unidos",
    "United States" : "Estados Unidos",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbequistão",
    "Holy See" : "Santa Sé",
    "Saint Vincent and the Grenadines" : "São Vicente e Granadinas",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Ilhas Virgens (Britânicas)",
    "Virgin Islands (U.S.)" : "Ilhas Virgens (U.S.)",
    "Vietnam" : "Vietnã",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iêmen",
    "Mayotte" : "Maiote",
    "South Africa" : "África do Sul",
    "Zambia" : "Zâmbia",
    "Zimbabwe" : "Zimbábue",
    "Your Nextcloud account" : "Sua conta Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Seus dados representam quem você é e podem ser facilmente usados. Na Nextcloud acreditamos que você tem o direito de decidir o que acontece com eles. O Nextcloud protege seus direitos conforme definido no Manifesto de Dados do Usuário!",
    "User Data Manifesto 2.0" : "Manifesto de Dados do Usuário 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definição dos direitos básicos para as pessoas controlarem seus próprios dados na era da internet",
    "Control" : "Controle",
    "over user data access" : "sobre o acesso aos dados do usuário",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Os dados carregados explicitamente e de bom grado por um usuário devem estar sob o controle final dele. Os usuários podem decidir quem tem acesso direto aos dados e com quais permissões e licenças esse acesso deve ser concedido.",
    "Knowledge" : "Conhecimento",
    "of how the data is stored" : "de como os dados são armazenados",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quando os dados são carregados em um provedor de serviços específico, os usuários devem ser informados sobre onde ele armazena os dados, por quanto tempo, em qual jurisdição o provedor de serviços específico opera e quais leis se aplicam.",
    "Freedom" : "Liberdade",
    "to choose a platform" : "para escolher uma plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Os usuários podem extrair seus dados do serviço a qualquer momento sem qualquer bloqueio do fornecedor. Padrões abertos para formatos e protocolos são necessários para garantir isso.",
    "Learn more ↗" : "Saiba mais ↗",
    "Where is your data?" : "Onde estão seus dados?",
    "Who has access to your data?" : "Quem tem acesso aos seus dados?",
    "Administrators" : "Administradores",
    "People you shared with" : "Pessoas com quem você compartilhou",
    "Privacy policy" : "Política de privacidade",
    "Read the privacy policy." : "Leia a política de privacidade.",
    "Encryption" : "Criptografia",
    "Please select a country" : "Selecione um país",
    "Bosnia and Herzegowina" : "Bósnia e Herzegovina"
},
"nplurals=2; plural=(n > 1);");
